@@ -7,6 +7,7 @@ import sys
 import threading
 import shutil
 import pandas as pd
+import numpy as np
 from tqdm import tqdm
 from queue import Queue
 from fast_sql.utils.exception import DB_Exceptions
@@ -26,9 +27,10 @@ class Read_sql:
         desc=None,
         columns_upper=True,
         auto_order=False,
+        is_make_dsn=False,
     ):
         if con is not None:
-            self.db_pool = Sqlalchemy_Pool(con, num=thread_num + 6, encoding=encoding)
+            self.db_pool = Sqlalchemy_Pool(con, num=thread_num + 6, encoding=encoding,is_make_dsn=is_make_dsn)
             self.driver = self.db_pool.driver
         self.sql = sql.strip().replace("\n", " ")
         self.thread_num = thread_num
@@ -259,7 +261,7 @@ class to_sql(Read_sql):
         self.extra_param = kwargs.pop('extra_param',None)
         super().__init__(*args, **kwargs)
         if to_db is not None:
-            self.to_db = DB_Pool(to_db, num=8, encoding=kwargs.get("encoding"))
+            self.to_db = DB_Pool(to_db, num=8, encoding=kwargs.get("encoding"),is_make_dsn=kwargs.get('is_make_dsn',False))
             self.write_driver = self.to_db.driver
         self.lock_b = threading.Lock()
         self.execute_pool = None
@@ -418,7 +420,7 @@ class to_sql(Read_sql):
         if self.write_driver == "mysql":
             for column, date in c:
                 df[column] = df[column].astype("str")
-                df.replace("NaT", None, inplace=True)
+                df.replace("NaT", np.NaN, inplace=True)
         else:
             for column, date in c:
                 df[column] = df[column].astype("object")
